summaryrefslogtreecommitdiff
path: root/storage/innobase/mem/mem0pool.cc
diff options
context:
space:
mode:
Diffstat (limited to 'storage/innobase/mem/mem0pool.cc')
-rw-r--r--storage/innobase/mem/mem0pool.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/storage/innobase/mem/mem0pool.cc b/storage/innobase/mem/mem0pool.cc
index 2135926a26f..fe9a84d21fa 100644
--- a/storage/innobase/mem/mem0pool.cc
+++ b/storage/innobase/mem/mem0pool.cc
@@ -100,12 +100,12 @@ pool, and after that its locks will grow into the buffer pool. */
/** Data structure for a memory pool. The space is allocated using the buddy
algorithm, where free list i contains areas of size 2 to power i. */
-struct mem_pool_struct{
+struct mem_pool_t{
byte* buf; /*!< memory pool */
ulint size; /*!< memory common pool size */
ulint reserved; /*!< amount of currently allocated
memory */
- mutex_t mutex; /*!< mutex protecting this struct */
+ ib_mutex_t mutex; /*!< mutex protecting this struct */
UT_LIST_BASE_NODE_T(mem_area_t)
free_list[64]; /*!< lists of free memory areas: an
area is put to the list whose number
@@ -116,7 +116,7 @@ struct mem_pool_struct{
UNIV_INTERN mem_pool_t* mem_comm_pool = NULL;
#ifdef UNIV_PFS_MUTEX
/* Key to register mutex in mem_pool_struct with performance schema */
UNIV_INTERN mysql_pfs_key_t mem_pool_mutex_key;
#endif /* UNIV_PFS_MUTEX */
@@ -116,7 +116,7 @@ struct mem_pool_struct{
UNIV_INTERN mem_pool_t* mem_comm_pool = NULL;
#ifdef UNIV_PFS_MUTEX
-/* Key to register mutex in mem_pool_struct with performance schema */
+/* Key to register mutex in mem_pool_t with performance schema */
UNIV_INTERN mysql_pfs_key_t mem_pool_mutex_key;
#endif /* UNIV_PFS_MUTEX */